from .mapper import enum_mapper, enum_mapper_from, map_to, mapper, mapper_from
from .mapping_method import Spezial, assume_not_none, init_with_default, provide_with_extra

USE_DEFAULT = Spezial.USE_DEFAULT
IGNORE_MISSING_MAPPING = Spezial.IGNORE_MISSING_MAPPING

__all__ = [
    "map_to",
    "mapper",
    "mapper_from",
    "enum_mapper",
    "enum_mapper_from",
    "USE_DEFAULT",
    "IGNORE_MISSING_MAPPING",
    "init_with_default",
    "assume_not_none",
    "provide_with_extra",
]
